#
# Conditional build:
%bcond_without	aom	# AVIF support via AOM
%bcond_without	webp	# WEBP support

Summary:	Tool to compute (dis)similarity between two or more images
Summary(pl.UTF-8):	Narzędzie do obliczania (nie)podobieństwa dwóch lub większej liczby obrazów
Name:		dssim2
Version:	3.4.0
Release:	1
License:	AGPL v3+ or commercial
Group:		Applications/Graphics
#Source0Download: https://github.com/kornelski/dssim/releases
Source0:	https://github.com/kornelski/dssim/archive/%{version}/dssim-%{version}.tar.gz
# Source0-md5:	c220e2b2c9cebdfc1e4faf0ccfad570b
# cd dssim-%{version}
# cargo vendor-filterer --platform='*-unknown-linux-*' --tier=2 --features avif,webp
# cd ..
# tar cJf dssim-vendor-%{version}.tar.xz dssim-%{version}/{vendor,Cargo.lock}
Source1:	dssim-vendor-%{version}.tar.xz
# Source1-md5:	fb6facbe03cb6236db8c646937d52892
URL:		https://kornel.ski/dssim
%{?with_aom:BuildRequires:	aom-devel >= 3.10.0}
BuildRequires:	cargo
BuildRequires:	cargo-c
BuildRequires:	lcms2-devel >= 2.16
%{?with_webp:BuildRequires:	libwebp-devel}
%ifarch %{ix86} %{x8664} x32
BuildRequires:	nasm
%endif
BuildRequires:	rpmbuild(macros) >= 2.004
BuildRequires:	rust
BuildRequires:	sed >= 4.0
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
%{?with_aom:Requires:	aom >= 3.10.0}
Requires:	lcms2 >= 2.16
Obsoletes:	dssim < 2
ExclusiveArch:	%{x8664} %{ix86} x32 aarch64 armv6hl armv7hl armv7hnl
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
This tool computes (dis)similarity between two or more PNG images
using an algorithm approximating human vision.

Comparison is done using the SSIM algorithm at multiple weighed
resolutions.

%description -l pl.UTF-8
To narzędzie oblicza (nie)podobieństwo dwóch lub większej liczby
obrazów PNG przy użyciu algorytmu przybliżającego ludzkie widzenie.

Porównywanie jest wykonywane algorytmem SSIM z wieloma ważonymi
rozdzielczościami.

%package libs
Summary:	DSSIM shared library
Summary(pl.UTF-8):	Biblioteka współdzielona DSSIM
Group:		Libraries
# not yet, library name and API differs, functionality is a subset
#Obsoletes:	dssim-libs < 2

%description libs
DSSIM shared library to compute (dis)similarity between two or more
images.

%description libs -l pl.UTF-8
Biblioteka współdzielona DSSIM do obliczania (nie)podobieństwa dwóch
lub większej liczby obrazów.

%package devel
Summary:	Header file for DSSIM library
Summary(pl.UTF-8):	Plik nagłówkowy biblioteki DSSIM
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Conflicts:	dssim-devel < 2

%description devel
Header file for DSSIM library.

%description devel -l pl.UTF-8
Plik nagłówkowy biblioteki DSSIM.

%package static
Summary:	Static DSSIM library
Summary(pl.UTF-8):	Statyczna biblioteka DSSIM
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static DSSIM library.

%description static -l pl.UTF-8
Statyczna biblioteka DSSIM.

%prep
%setup -q -n dssim-%{version} -b1

# use our offline registry
export CARGO_HOME="$(pwd)/.cargo"

mkdir -p "$CARGO_HOME"
cat >.cargo/config.toml <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'

[source.vendored-sources]
directory = '$PWD/vendor'
EOF

# shared aom (also fixes x32 build, builtin aom linking fails)
%{__sed} -i -e 's/cargo:rustc-link-lib=static=aom/cargo:rustc-link-lib=aom/' vendor/libaom-sys/build.rs
%{__sed} -i -e 's/"build.rs":"8d94ba3471da74dd30bf1af5fb1d3c080c605bc59a9f09587b0123b516576cc8"/"build.rs":"8e132aec467850ebc0bfd4cc69f8e951532a2f9b055a8a40c0fbff232a0ea931"/' vendor/libaom-sys/.cargo-checksum.json

# shared lcms2
%{__sed} -i -e '/^load_image = / s/, features = \["lcms2-static"\]//' Cargo.toml

%build
export CARGO_HOME="$(pwd)/.cargo"
export LIB_AOM_INCLUDE_PATH=%{_includedir}
export LIB_AOM_PKG_CONFIG_PATH=%{_pkgconfigdir}
export LIB_AOM_STATIC_LIB_PATH=%{_libdir}

%cargo_build --frozen \
	--features "%{?with_aom:avif} %{?with_webp:webp}"

cd dssim-core
%{__cargo} %{__cargo_common_opts} cbuild \
	%{!?debug:--release} \
	--target %{rust_target} \
	--target-dir %{cargo_targetdir} \
	--prefix %{_prefix} \
	--libdir %{_libdir}

%install
rm -rf $RPM_BUILD_ROOT

export CARGO_HOME="$(pwd)/.cargo"
export LIB_AOM_INCLUDE_PATH=%{_includedir}
export LIB_AOM_PKG_CONFIG_PATH=%{_pkgconfigdir}
export LIB_AOM_STATIC_LIB_PATH=%{_libdir}

%cargo_install --frozen \
	--features "%{?with_aom:avif} %{?with_webp:webp}" \
	--path . \
	--root $RPM_BUILD_ROOT%{_prefix}

cd dssim-core
%{__cargo} %{__cargo_common_opts} cinstall \
	--destdir $RPM_BUILD_ROOT \
	%{!?debug:--release} \
	--target %{rust_target} \
	--target-dir %{cargo_targetdir} \
	--prefix %{_prefix} \
	--libdir %{_libdir}

%clean
rm -rf $RPM_BUILD_ROOT

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc README.md
%attr(755,root,root) %{_bindir}/dssim

%files libs
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libdssim.so.*.*.*
%ghost %{_libdir}/libdssim.so.3

%files devel
%defattr(644,root,root,755)
%{_libdir}/libdssim.so
%{_includedir}/dssim.h
%{_pkgconfigdir}/dssim.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libdssim.a
%changelog
* Wed Apr 16 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/dssim2.git;a=log;h=master

* Wed Apr 16 2025 Jakub Bogusz <qboosh@pld-linux.org> ce318a2
- Conflicts, not Obsoletes dssim-devel (not a replacement yet)

* Sun Mar 23 2025 Jakub Bogusz <qboosh@pld-linux.org> b715275
- ldconfig

* Sun Mar 23 2025 Jakub Bogusz <qboosh@pld-linux.org> 8334015
- obsolete dssim-devel

* Sat Mar 22 2025 Jakub Bogusz <qboosh@pld-linux.org> 82d65fc
- build with C interface

* Sat Mar 22 2025 Jakub Bogusz <qboosh@pld-linux.org> 3ca3955
- updated to 3.4.0

* Sun Oct 22 2023 Jakub Bogusz <qboosh@pld-linux.org> d0d3c29
- force system aom and lcms2; the first fixes x32 build

* Sat Oct 21 2023 Jakub Bogusz <qboosh@pld-linux.org> a46a9d1
- updated to 3.2.3

* Tue Mar 01 2022 Jakub Bogusz <qboosh@pld-linux.org> 69a95dc
- updated to 3.2.0
- nasm-rs-x32 patch seems obsolete

* Sat Feb 26 2022 Jakub Bogusz <qboosh@pld-linux.org> 832db21
- restored Obsoletes, it refers to dssim *tool*, not library

* Wed Feb 23 2022 Jan Rękorajski <baggins@pld-linux.org> 0131577
- do not obsolete a library if not providing it

* Mon Jan 24 2022 Jan Palus <atler@pld-linux.org> e2c9d3c
- BRs for tar.xz source

* Mon Jan 24 2022 Jan Palus <atler@pld-linux.org> a3816de
- macros for %cargo*

* Mon Jan 24 2022 Jan Palus <atler@pld-linux.org> 2726e75
- attempt at adding support for x32 target in nasm compiled sources

* Mon Jan 24 2022 Jan Palus <atler@pld-linux.org> a184185
- BR: nasm on x86 (for avx/sse asm in mozjpeg)

* Mon Jan 24 2022 Jan Palus <atler@pld-linux.org> 5e1f7c6
- use rust macros

* Tue Dec 28 2021 Jakub Bogusz <qboosh@pld-linux.org> fcfcef6
- disable debugsource packages, updated archs list

* Tue Dec 28 2021 Jakub Bogusz <qboosh@pld-linux.org> 48a35a4
- updated to 3.0.2

* Thu Apr 18 2019 Jakub Bogusz <qboosh@pld-linux.org> 503f6f6
- updated to 2.10.0
- add vendored creates as additional source for offline build

* Sat Dec 23 2017 Jakub Bogusz <qboosh@pld-linux.org> a0b2520
- updated to 2.9.4
- packaging as dssim2 because of rust rewrite regressions (archs limited to x86* and no x32 ABI; no C library)

* Sat Jul 29 2017 Jakub Bogusz <qboosh@pld-linux.org> b6b0beb
- pass libdir to meson

